Enum Fsoff
#[repr(u8)]pub enum Fsoff {
OnFirst = 0,
BeforeFirst = 1,
}Variants
OnFirst = 0
FS is asserted on the first bit of the slot 0
BeforeFirst = 1
FS is asserted one bit before the first bit of the slot 0
Implementations